@@ -21,11 +21,9 @@
 #include "fileexcludefilters.h"
 #include "storagedevices.h"
 
-#include <QUrl>
 #include <QStringList>
 #include <QDir>
 
-#include <KDirWatch>
 #include <QStandardPaths>
 #include <KConfigGroup>
 #include <QDebug>
@@ -47,23 +45,23 @@ bool isDirHidden(QDir& dir)
         return false;
 #endif
 }
+
+QString stripTrailingSlash(const QString& path)
+{
+    return path.endsWith('/') ? path.mid(0, path.length()-1) : path;
+}
+
 }
 
 using namespace Baloo;
 
 FileIndexerConfig::FileIndexerConfig(QObject* parent)
     : QObject(parent)
-    , m_config(QLatin1String("baloofilerc"), KConfig::SimpleConfig)
+    , m_config(QStringLiteral("baloofilerc"))
     , m_indexHidden(false)
     , m_devices(new StorageDevices(this))
+    , m_maxUncomittedFiles(40)
 {
-    KDirWatch* dirWatch = KDirWatch::self();
-    connect(dirWatch, SIGNAL(dirty(QString)),
-            this, SLOT(slotConfigDirty()));
-    connect(dirWatch, SIGNAL(created(QString)),
-            this, SLOT(slotConfigDirty()));
-    dirWatch->addFile(QStandardPaths::locate(QStandardPaths::ConfigLocation, m_config.name()));
-
     forceConfigUpdate();
 }
 
@@ -119,6 +117,10 @@ QStringList FileIndexerConfig::excludeFilters() const
     return QStringList::fromSet(filters);
 }
 
+QStringList FileIndexerConfig::excludeMimetypes() const
+{
+    return QStringList::fromSet(m_excludeMimetypes);
+}
 
 bool FileIndexerConfig::indexHiddenFilesAndFolders() const
 {
@@ -130,13 +132,6 @@ bool FileIndexerConfig::onlyBasicIndexing() const
     return m_onlyBasicIndexing;
 }
 
-void FileIndexerConfig::slotConfigDirty()
-{
-    forceConfigUpdate();
-    Q_EMIT configChanged();
-}
-
-
 bool FileIndexerConfig::isInitialRun() const
 {
     return m_config.group("General").readEntry("first run", true);
@@ -190,7 +185,9 @@ bool FileIndexerConfig::shouldFolderBeIndexed(const QString& path) const
 
 bool FileIndexerConfig::shouldFileBeIndexed(const QString& fileName) const
 {
-    // check the filters
+    if (!indexHiddenFilesAndFolders() && fileName.startsWith('.')) {
+        return false;
+    }
     return !m_excludeFilterRegExpCache.exactMatch(fileName);
 }
 
@@ -208,7 +205,7 @@ bool FileIndexerConfig::folderInFolderList(const QString& path)
 
 bool FileIndexerConfig::folderInFolderList(const QString& path, QString& folder) const
 {
-    const QString p = QUrl(path).adjusted(QUrl::StripTrailingSlash).path();
+    const QString p = stripTrailingSlash(path);
 
     // we traverse the list backwards to catch all exclude folders
     int i = m_folderCache.count();
@@ -236,7 +233,7 @@ bool alreadyExcluded(const QList<QPair<QString, bool> >& folders, const QString&
 {
     bool included = false;
     for (int i = 0; i < folders.count(); ++i) {
-        QString path = QUrl(folders[i].first).path();
+        QString path = folders[i].first;
         if (!path.endsWith(QLatin1Char('/')))
             path.append(QLatin1Char('/'));
 
@@ -254,7 +251,7 @@ void insertSortFolders(const QStringList& folders, bool include, QList<QPair<QSt
 {
     Q_FOREACH (const QString& f, folders) {
         int pos = 0;
-        QString path = QUrl(f).adjusted(QUrl::StripTrailingSlash).path();
+        QString path = stripTrailingSlash(f);
         while (result.count() > pos &&
                 result[pos].first < path)
             ++pos;
@@ -289,7 +286,7 @@ void FileIndexerConfig::buildFolderCache()
 
     // Add all removable media and network shares as ignored unless they have
     // been explicitly added in the include list
-    for (auto device: m_devices->allMedia()) {
+    for (const auto& device: m_devices->allMedia()) {
         const QString mountPath = device.mountPath();
         if (!device.isUsable() && !mountPath.isEmpty()) {
             if (!includeFoldersPlain.contains(mountPath)) {
@@ -339,3 +336,25 @@ bool FileIndexerConfig::initialUpdateDisabled() const
 {
     return m_config.group("General").readEntry("disable initial update", true);
 }
+
+int FileIndexerConfig::databaseVersion() const
+{
+    return m_config.group("General").readEntry("dbVersion", 0);
+}
+
+void FileIndexerConfig::setDatabaseVersion(int version)
+{
+    m_config.group("General").writeEntry("dbVersion", version);
+    m_config.sync();
+}
+
+bool FileIndexerConfig::indexingEnabled() const
+{
+    return m_config.group("Basic Settings").readEntry("Indexing-Enabled", true);
+}
+
+uint FileIndexerConfig::maxUncomittedFiles()
+{
+    return m_maxUncomittedFiles;
+}
+
